@@ -513,6 +513,7 @@ build_single_doc_dialog (PlumaCloseConfirmationDialog *dlg)
 #endif
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 	gtk_widget_set_can_focus (GTK_WIDGET (primary_label), FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (primary_label), 72);
 
 	doc_name = pluma_document_get_short_name_for_display (doc);
 
@@ -550,6 +551,7 @@ build_single_doc_dialog (PlumaCloseConfirmationDialog *dlg)
 #endif
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 	gtk_widget_set_can_focus (GTK_WIDGET (secondary_label), FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (secondary_label), 72);
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
@@ -710,6 +712,8 @@ build_multiple_docs_dialog (PlumaCloseConfirmationDialog *dlg)
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
 #endif
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
+	gtk_widget_set_can_focus (GTK_WIDGET (primary_label), FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (primary_label), 72);
 
 	if (priv->disable_save_to_disk)
 		str = g_strdup_printf (
@@ -743,11 +747,14 @@ build_multiple_docs_dialog (PlumaCloseConfirmationDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (vbox2), select_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (select_label), TRUE);
+	gtk_label_set_max_width_chars (GTK_LABEL (select_label), 72);
 #if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (select_label), 0.0);
 #else
 	gtk_misc_set_alignment (GTK_MISC (select_label), 0.0, 0.5);
 #endif
+	gtk_label_set_selectable (GTK_LABEL (select_label), TRUE);
+	gtk_widget_set_can_focus (GTK_WIDGET (select_label), FALSE);
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow, TRUE, TRUE, 0);
@@ -775,6 +782,8 @@ build_multiple_docs_dialog (PlumaCloseConfirmationDialog *dlg)
 	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
 #endif
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
+	gtk_widget_set_can_focus (GTK_WIDGET (secondary_label), FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (secondary_label), 72);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
 
